@@ -1,5 +1,5 @@
 #
-# $Id: Context.pm,v f488542c2796 2016/10/11 17:04:47 gomor $
+# $Id: Context.pm,v 9685bb4e1534 2017/01/01 10:20:58 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
@@ -7,13 +7,13 @@ use warnings;
 
 # Breaking.Feature.Fix
 our $VERSION = '1.25';
-our $FIX = '0';
+our $FIX = '1';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f488542c2796 $',
+      revision => '$Revision: 9685bb4e1534 $',
       tags => [ qw(main core) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
@@ -477,7 +477,7 @@ sub reuse {
    }
 
    for (@reloaded) {
-      $self->log->verbose("reuse: module [$_] successfully reloaded");
+      $self->log->info("reuse: module [$_] successfully reloaded");
    }
 
    return 1;
@@ -1008,7 +1008,7 @@ L<Metabrik>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
