@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v f488542c2796 2016/10/11 17:04:47 gomor $
+# $Id: Shell.pm,v 9685bb4e1534 2017/01/01 10:20:58 gomor $
 #
 # core::shell Brik
 #
@@ -9,7 +9,7 @@ use warnings;
 
 # Breaking.Feature.Fix
 our $VERSION = '1.25';
-our $FIX = '0';
+our $FIX = '1';
 
 use base qw(Term::Shell Metabrik);
 
@@ -17,7 +17,7 @@ use IO::All;
 
 sub brik_properties {
    return {
-      revision => '$Revision: f488542c2796 $',
+      revision => '$Revision: 9685bb4e1534 $',
       tags => [ qw(main core) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -76,7 +76,10 @@ sub brik_properties {
          show_inherited_all => 0,
          show_all => 0,
          aliases_completion => 0,
-         capture_mode => 1,
+         #capture_mode => 1,
+         capture_mode => 0,  # Do not capture by default.
+                             # It makes users uncertain of what is happening
+                             # when executing any external command.
       },
       commands => {
          splash => [ ],
@@ -1743,7 +1746,7 @@ L<Metabrik>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
